summaryrefslogtreecommitdiffstats
path: root/src/import
diff options
context:
space:
mode:
authorClaus Michael Olsen <cmolsen@us.ibm.com>2018-08-08 09:53:58 -0500
committerSachin Gupta <sgupta2m@in.ibm.com>2018-09-06 23:41:51 -0500
commit225922537f456e7e05d79bb737178066001159f7 (patch)
tree69685148b0f483ff845480b52a6d3e291ff3605f /src/import
parent26f2defa140d92f36dce828fece5cd12bec35e11 (diff)
downloadtalos-sbe-225922537f456e7e05d79bb737178066001159f7.tar.gz
talos-sbe-225922537f456e7e05d79bb737178066001159f7.zip
Infrastructure support for new MC OMI rings for Axone
Key_Cronus_Test=XIP_REGRESS Change-Id: I931305965d8f463233c5c30a3f561c93a4e2e08a Reviewed-on: http://rchgit01.rchland.ibm.com/gerrit1/64115 Tested-by: Jenkins Server <pfd-jenkins+hostboot@us.ibm.com> Tested-by: HWSV CI <hwsv-ci+hostboot@us.ibm.com> Tested-by: PPE CI <ppe-ci+hostboot@us.ibm.com> Tested-by: Hostboot CI <hostboot-ci+hostboot@us.ibm.com> Reviewed-by: Anusha Reddy Rangareddygari <anusrang@in.ibm.com> Reviewed-by: SRINIVAS V. POLISETTY <srinivan@in.ibm.com> Reviewed-by: Jennifer A. Stofer <stofer@us.ibm.com> Reviewed-on: http://rchgit01.rchland.ibm.com/gerrit1/64127 Tested-by: FSP CI Jenkins <fsp-CI-jenkins+hostboot@us.ibm.com> Reviewed-by: Sachin Gupta <sgupta2m@in.ibm.com>
Diffstat (limited to 'src/import')
-rw-r--r--src/import/chips/p9/utils/imageProcs/p9_ringId.C21
-rw-r--r--src/import/chips/p9/utils/imageProcs/p9_ringId.H61
-rw-r--r--src/import/chips/p9/utils/imageProcs/p9_ring_id.h17
3 files changed, 80 insertions, 19 deletions
diff --git a/src/import/chips/p9/utils/imageProcs/p9_ringId.C b/src/import/chips/p9/utils/imageProcs/p9_ringId.C
index f03ca39a..33d730a0 100644
--- a/src/import/chips/p9/utils/imageProcs/p9_ringId.C
+++ b/src/import/chips/p9/utils/imageProcs/p9_ringId.C
@@ -55,11 +55,14 @@ const GenRingIdList RING_ID_LIST_COMMON[] =
{"perv_pll_bndy_flt_2" , 0x10, 0x01, 0x01, EKB_NONFLUSH_RING, 0x01030018},
{"perv_pll_bndy_flt_3" , 0x11, 0x01, 0x01, EKB_NONFLUSH_RING, 0x01030018},
{"perv_pll_bndy_flt_4" , 0x12, 0x01, 0x01, EKB_NONFLUSH_RING, 0x01030018},
+ {"sbe_fure" , 0x13, 0x01, 0x01, EKB_RING , 0x0103020F},
+ {"sbe_gptr" , 0x14, 0x01, 0x01, EKB_RING , 0x01030202},
};
const GenRingIdList RING_ID_LIST_INSTANCE[] =
{
- {"perv_repr" , 0x13, 0x01, 0x01, VPD_RING , 0x01034006},
- {"occ_repr" , 0x14, 0x01, 0x01, VPD_RING , 0x01030806},
+ {"perv_repr" , 0x15, 0x01, 0x01, VPD_RING , 0x01034006},
+ {"occ_repr" , 0x16, 0x01, 0x01, VPD_RING , 0x01030806},
+ {"sbe_repr" , 0x17, 0x01, 0x01, VPD_RING , 0x01030206},
};
const RingVariantOrder RING_VARIANT_ORDER[] = { RV_BASE, RV_RL, UNDEFINED_RING_VARIANT, UNDEFINED_RING_VARIANT, UNDEFINED_RING_VARIANT, UNDEFINED_RING_VARIANT, UNDEFINED_RING_VARIANT };
};
@@ -216,11 +219,21 @@ const GenRingIdList RING_ID_LIST_COMMON[] =
{"mc_pll_bndy_bucket_4", 0x0d, 0x07, 0x07, EKB_RING , 0x07030018},
{"mc_pll_bndy_bucket_5", 0x0e, 0x07, 0x07, EKB_RING , 0x07030018},
{"mc_pll_func" , 0x0f, 0x07, 0x07, EKB_RING , 0x07030010},
+ {"mc_omi0_fure" , 0x10, 0x07, 0x08, EKB_RING , 0x0703100F},
+ {"mc_omi0_gptr" , 0x11, 0x07, 0x07, EKB_RING , 0x07031002},
+ {"mc_omi1_fure" , 0x12, 0x07, 0x07, EKB_RING , 0x0703080F},
+ {"mc_omi1_gptr" , 0x13, 0x07, 0x07, EKB_RING , 0x07030802},
+ {"mc_omi2_fure" , 0x14, 0x07, 0x07, EKB_RING , 0x0703040F},
+ {"mc_omi2_gptr" , 0x15, 0x07, 0x07, EKB_RING , 0x07030402},
+ {"mc_omippe_fure" , 0x16, 0x07, 0x07, EKB_RING , 0x0703020F},
+ {"mc_omippe_gptr" , 0x17, 0x07, 0x07, EKB_RING , 0x07030202},
+ {"mc_omippe_time" , 0x18, 0x07, 0x07, VPD_RING , 0x07030207},
};
const GenRingIdList RING_ID_LIST_INSTANCE[] =
{
- {"mc_repr" , 0x10, 0x07, 0x08, VPD_RING , 0x07036006},
- {"mc_iom23_repr" , 0x11, 0x07, 0x08, VPD_RING , 0x07030806},
+ {"mc_repr" , 0x19, 0x07, 0x08, VPD_RING , 0x07036006},
+ {"mc_iom23_repr" , 0x1a, 0x07, 0x08, VPD_RING , 0x07030806},
+ {"mc_omippe_repr" , 0x1b, 0x07, 0x08, VPD_RING , 0x07030206},
};
const RingVariantOrder RING_VARIANT_ORDER[] = { RV_BASE, RV_RL, UNDEFINED_RING_VARIANT, UNDEFINED_RING_VARIANT, UNDEFINED_RING_VARIANT, UNDEFINED_RING_VARIANT, UNDEFINED_RING_VARIANT };
};
diff --git a/src/import/chips/p9/utils/imageProcs/p9_ring_id.h b/src/import/chips/p9/utils/imageProcs/p9_ring_id.h
index 47fe2f5b..dc9d5dfb 100644
--- a/src/import/chips/p9/utils/imageProcs/p9_ring_id.h
+++ b/src/import/chips/p9/utils/imageProcs/p9_ring_id.h
@@ -64,7 +64,9 @@ enum RingID
perv_pll_func = 15, //0x0F
perv_repr = 16, //0x10
occ_repr = 17, //0x11
- // values 18-20 unused
+ sbe_fure = 18, //0x12
+ sbe_gptr = 19, //0x13
+ sbe_repr = 20, //0x14
// Nest Chiplet Rings - N0
n0_fure = 21, //0x15
@@ -369,6 +371,19 @@ enum RingID
perv_pll_bndy_flt_3 = 255, //0xFF
perv_pll_bndy_flt_4 = 256, //0x100
+ // MC OMI rings
+ mc_omi0_fure = 257, //0x101
+ mc_omi0_gptr = 258, //0x102
+ mc_omi1_fure = 259, //0x103
+ mc_omi1_gptr = 260, //0x104
+ mc_omi2_fure = 261, //0x105
+ mc_omi2_gptr = 262, //0x106
+ mc_omippe_fure = 263, //0x107
+ mc_omippe_gptr = 264, //0x108
+ mc_omippe_time = 265, //0x109
+ // Instance rings
+ mc_omippe_repr = 266, //0x10A
+
//***************************
// Rings needed for SBE - End
//***************************
OpenPOWER on IntegriCloud
diff --git a/src/import/chips/p9/utils/imageProcs/p9_ringId.H b/src/import/chips/p9/utils/imageProcs/p9_ringId.H
index e090acc7..44c15063 100644
--- a/src/import/chips/p9/utils/imageProcs/p9_ringId.H
+++ b/src/import/chips/p9/utils/imageProcs/p9_ringId.H
@@ -203,17 +203,20 @@ enum RingOffset
perv_pll_bndy_flt_2 = 16,
perv_pll_bndy_flt_3 = 17,
perv_pll_bndy_flt_4 = 18,
+ sbe_fure = 19,
+ sbe_gptr = 20,
// Instance Rings
perv_repr = (0 | INSTANCE_RING_MARK),
occ_repr = (1 | INSTANCE_RING_MARK),
+ sbe_repr = (2 | INSTANCE_RING_MARK),
};
static const ChipletData_t g_chipletData =
{
1, // Pervasive Chiplet ID is 1
- 19, // 19 common rings for pervasive chiplet
- 2, // 2 instance specific rings for pervasive chiplet
- 2,
+ 21, // 21 common rings for pervasive chiplet
+ 3, // 3 instance specific rings for pervasive chiplet
+ 3,
2, // 2 common ring variants: BASE, RL
};
}; // end of namespace PERV
@@ -401,17 +404,27 @@ enum RingOffset
mc_pll_bndy_bucket_4 = 13,
mc_pll_bndy_bucket_5 = 14,
mc_pll_func = 15,
+ mc_omi0_fure = 16,
+ mc_omi0_gptr = 17,
+ mc_omi1_fure = 18,
+ mc_omi1_gptr = 19,
+ mc_omi2_fure = 20,
+ mc_omi2_gptr = 21,
+ mc_omippe_fure = 22,
+ mc_omippe_gptr = 23,
+ mc_omippe_time = 24,
// Instance Rings
- mc_repr = (0 | INSTANCE_RING_MARK),
- mc_iom23_repr = (1 | INSTANCE_RING_MARK),
+ mc_repr = (0 | INSTANCE_RING_MARK),
+ mc_iom23_repr = (1 | INSTANCE_RING_MARK),
+ mc_omippe_repr = (2 | INSTANCE_RING_MARK),
};
static const ChipletData_t g_chipletData =
{
7, // MC Chiplet ID range is 7 - 8. The base ID is 7.
- 16, // 16 common rings for MC Chiplet
- 2, // 1 instance specific rings for each MC instance
- 2,
+ 25, // 25 common rings for MC Chiplet
+ 3, // 3 instance specific rings for each MC instance
+ 3,
2, // 2 common ring variants: BASE, RL
};
}; // end of namespace MC
@@ -736,9 +749,9 @@ static const RingProperties_t RING_PROPERTIES[NUM_RING_IDS] =
{ PERV::perv_pll_func , "perv_pll_func" , PERV_TYPE }, // 15
{ PERV::perv_repr , "perv_repr" , PERV_TYPE }, // 16
{ PERV::occ_repr , "occ_repr" , PERV_TYPE }, // 17
- { INVALID_RING_OFFSET , "invalid" , PERV_TYPE }, // 18
- { INVALID_RING_OFFSET , "invalid" , PERV_TYPE }, // 19
- { INVALID_RING_OFFSET , "invalid" , PERV_TYPE }, // 20
+ { PERV::sbe_fure , "sbe_fure" , PERV_TYPE }, // 18
+ { PERV::sbe_gptr , "sbe_gptr" , PERV_TYPE }, // 19
+ { PERV::sbe_repr , "sbe_repr" , PERV_TYPE }, // 20
{ N0::n0_fure , "n0_fure" , N0_TYPE }, // 21
{ N0::n0_gptr , "n0_gptr" , N0_TYPE }, // 22
{ N0::n0_time , "n0_time" , N0_TYPE }, // 23
@@ -975,6 +988,16 @@ static const RingProperties_t RING_PROPERTIES[NUM_RING_IDS] =
{ PERV::perv_pll_bndy_flt_2 , "perv_pll_bndy_flt_2" , PERV_TYPE }, // 254
{ PERV::perv_pll_bndy_flt_3 , "perv_pll_bndy_flt_3" , PERV_TYPE }, // 255
{ PERV::perv_pll_bndy_flt_4 , "perv_pll_bndy_flt_4" , PERV_TYPE }, // 256
+ { MC::mc_omi0_fure , "mc_omi0_fure" , MC_TYPE }, // 257
+ { MC::mc_omi0_gptr , "mc_omi0_gptr" , MC_TYPE }, // 258
+ { MC::mc_omi1_fure , "mc_omi1_fure" , MC_TYPE }, // 259
+ { MC::mc_omi1_gptr , "mc_omi1_gptr" , MC_TYPE }, // 260
+ { MC::mc_omi2_fure , "mc_omi2_fure" , MC_TYPE }, // 261
+ { MC::mc_omi2_gptr , "mc_omi2_gptr" , MC_TYPE }, // 262
+ { MC::mc_omippe_fure , "mc_omippe_fure" , MC_TYPE }, // 263
+ { MC::mc_omippe_gptr , "mc_omippe_gptr" , MC_TYPE }, // 264
+ { MC::mc_omippe_time , "mc_omippe_time" , MC_TYPE }, // 265
+ { MC::mc_omippe_repr , "mc_omippe_repr" , MC_TYPE }, // 266
};
#endif
@@ -999,9 +1022,9 @@ static const RingProperties_t RING_PROPERTIES[NUM_RING_IDS] =
{ PERV::perv_pll_func , PERV_TYPE }, // 15
{ PERV::perv_repr , PERV_TYPE }, // 16
{ PERV::occ_repr , PERV_TYPE }, // 17
- { INVALID_RING_OFFSET , PERV_TYPE }, // 18
- { INVALID_RING_OFFSET , PERV_TYPE }, // 19
- { INVALID_RING_OFFSET , PERV_TYPE }, // 20
+ { PERV::sbe_fure , PERV_TYPE }, // 18
+ { PERV::sbe_gptr , PERV_TYPE }, // 19
+ { PERV::sbe_repr , PERV_TYPE }, // 20
{ N0::n0_fure , N0_TYPE }, // 21
{ N0::n0_gptr , N0_TYPE }, // 22
{ N0::n0_time , N0_TYPE }, // 23
@@ -1238,6 +1261,16 @@ static const RingProperties_t RING_PROPERTIES[NUM_RING_IDS] =
{ PERV::perv_pll_bndy_flt_2 , PERV_TYPE }, // 254
{ PERV::perv_pll_bndy_flt_3 , PERV_TYPE }, // 255
{ PERV::perv_pll_bndy_flt_4 , PERV_TYPE }, // 256
+ { MC::mc_omi0_fure , MC_TYPE }, // 257
+ { MC::mc_omi0_gptr , MC_TYPE }, // 258
+ { MC::mc_omi1_fure , MC_TYPE }, // 259
+ { MC::mc_omi1_gptr , MC_TYPE }, // 260
+ { MC::mc_omi2_fure , MC_TYPE }, // 261
+ { MC::mc_omi2_gptr , MC_TYPE }, // 262
+ { MC::mc_omippe_fure , MC_TYPE }, // 263
+ { MC::mc_omippe_gptr , MC_TYPE }, // 264
+ { MC::mc_omippe_time , MC_TYPE }, // 265
+ { MC::mc_omippe_repr , MC_TYPE }, // 266
};
#endif